% Example 51a
% Binary Phase Shift Keying (BPSK)
% plot m(t)*Ac*cos(2*pi*fc*t)
% m(t) = +1 for binary 1
% m(t) = -1 for binary 0
% m(t) = ASCII code for K: 01001011
% t goes from 0 to 32 msec
%
m = 10;
fc = 1000;      % Hertz
tc = 1/fc;      % seconds
N = 2^m;                % N = 1024
Ncycles = 2^(m-5);      % Ncycles = 32
tmax = Ncycles*tc;      % 16 msec
Nbits = 8;
b1 = ones(1,N/Nbits);
b0 = -ones(1,N/Nbits);
mt = [b0 b1 b0 b0 b1 b0 b1 b1];     % 01001011
t = linspace(0,tmax,N); 
y = mt.*cos(2*pi*fc*t);
plot(t,y)
axis([0,tmax,-1.2,1.2]);
xticks(0:tmax/8:tmax);
xticklabels(0:tmax*1000/8:tmax*1000); % label milliseconds
xlabel('t (msec)'); 
title('Binary Phase Shift Keying (BPSK) 01001011');
