% Example 51b 
% Binary Phase Shift Keying (BPSK)
% plot DFT of m(t)*Ac*cos(2*pi*fc*t)
% m(t) = +1 for binary 1
% m(t) = -1 for binary 0
% m(t) = ASCII code for K: 01001011
% t goes from 0 to 16 msec
%
m = 10;
fc = 1000;      % Hertz
tc = 1/fc;      % seconds
N = 2^m;                % N = 1024
Ncycles = 2^(m-5);      % Ncycles = 32
tmax = Ncycles*tc;      % 16 msec
Nbits = 8;
b1 = ones(1,N/Nbits);
b0 = -ones(1,N/Nbits);
mt = [b0 b1 b0 b0 b1 b0 b1 b1];     % 01001011
t = linspace(0,tmax,N); 
y = mt.*cos(2*pi*fc*t);
Gkr = fft(y,N);
Gk = fftshift(Gkr);
magGk = abs(Gk)/Ac;
f = -N/2:N/2-1;
plot(f, magGk); 
axis([-N/6,N/6,-N/64,N/16]);
ax = gca;
ax.XAxisLocation = 'origin';
ax.YAxisLocation = 'origin';
xticks(-N/4:N/32:N/4);
xticklabels(-N/(4*tmax):N/(32*tmax):N/(4*tmax)); % label f (Hz)
ax.YTick = 0:N/64:N/2+N/16;
xlabel('f (Hz)'); ylabel('|G(k)|');
title('Magnitude of DFT: BPSK  01001011');
